#
# spec file for package python-ndindex
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-ndindex
Version:        1.8
Release:        1.1
Summary:        A Python library for manipulating indices of ndarrays
License:        MIT
URL:            https://quansight-labs.github.io/ndindex/
Source:         https://files.pythonhosted.org/packages/source/n/ndindex/ndindex-%{version}.tar.gz
# PATCH-FIX-OPENSUSE custom-pytest.patch gh#Quansight-Labs/ndindex#150
Patch2:         custom-pytest.patch
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Recommends:     python-numpy
# SECTION test requirements
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Python library for manipulating indices of ndarrays.

%prep
%autosetup -p1 -n ndindex-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%ifarch %{ix86}
# flaky on 32bit
donttest=("-k" "not test_as_subindex_hypothesis")
%endif
%pytest_arch --hypothesis-profile=obs "${donttest[@]}"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitearch}/ndindex
%{python_sitearch}/ndindex-%{version}.dist-info

%changelog
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 1.8:
  * Breaking broadcast_shapes() no longer returns None in the place
    of skipped axes. The result is now just the non-skipped axes
    broadcasted together.
  * The skip_axes flag to iter_indices() and broadcast_shapes() can
    now be a list of tuples, of skipped axes, which apply to each
    respective shape independently.
  * Mixing negative and nonnegative skip_axes in iter_indices() and
    broadcast_shapes() is now supported. The only restriction is
    that skip axes must refer to unique dimensions for each shape.
  * New index method selected_indices(), which iterates indices
    corresponding to each element selected by the given index on an
    array of a given shape.
  * ndindex indices can now be constructed by slicing the ndindex()
    constructor function, like ndindex[0:10]. This is generally
    preferred for indices with explicit slices, as this allows using
    the usual : slice syntax instead of requiring slices to be spelled
    out with the slice function.
  * Add a negative_int flag to reduce, which makes it normalize
    integer indices to negative integers when a shape is provided.
  * Slice objects now hash to the same hash value as their
    corresponding raw slice in Python 3.12, which now allows native
    slice objects to be hashed.
  * Fix an incorrect result from ChunkSize.as_subchunks() and
    ChunkSize.num_subchunks() when using multiple array indices or a
    boolean array index with multiple dimensions.
- drop ndindex-pr159-py312.patch (upstream)
* Wed Feb  7 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.7
  * Breaking: the skip_axes argument iter_indices() function now
    applies the skipped axes before broadcasting, not after. This
    behavior is more generally useful and matches how functions
    with stacking work (e.g., np.cross or np.matmul). The best way
    to get the old behavior is to broadcast the arrays/shapes
    together first. The skip_axes in iter_indices must be either
    all negative or all nonnegative to avoid ambiguity. A future
    version may add support for specifying different skip axes for
    each shape.
  * iter_indices() no longer requires the skipped axes specified by
    skip_axes to be broadcast compatible.
  * New method isvalid() to check if an index is valid on a given
    shape.
  * New function broadcast_shapes() which is the same as
    np.broadcast_shapes() except it also allows specifying a set of
    skip_axes which will be ignored when broadcasting.
  * New exceptions BroadcastError and AxisError which are used by
    iter_indices() and broadcast_shapes().
  * Fix some test failures with the latest version of NumPy.
  * Fix some tests that didn’t work properly when run against the
  * sdist.
  * The sdist now includes relevant testing files.
- Drop patches fixed upstream
  * ndindex-pr133-ragged.patch gh#Quansight-Labs/ndindex#133
  * ndindex-pr147-numpy.patch gh#Quansight-Labs/ndindex#147
- Refresh custom-pytest.patch gh#Quansight-Labs/ndindex#150
- Add ndindex-pr159-py312.patch gh#Quansight-Labs/ndindex#159
* Fri Mar 31 2023 Ben Greiner <code@bnavigator.de>
- Skip a flaky test in i586
* Thu Mar 30 2023 Ben Greiner <code@bnavigator.de>
- Initial specfile for v1.6
- Required by python-blosc2 2.1.1
- Add ndindex-pr133-ragged.patch gh#Quansight-Labs/ndindex#133
- Add ndindex-pr147-numpy.patch gh#Quansight-Labs/ndindex#147
- Add custom-pytest.patch
